==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: "Imap"

, "Hostname"
: ""

, "Username"
: "Gebruikersnaam"

, "Password"
: "Wachtwoord"

, "Port"
: "Poort"

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: "Nee"

, "Yes"
: "Ja"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: ""

, "MySql Database"
: ""

, "MySql User"
: ""

, "MySql Password"
: ""

, "MySql Port"
: ""

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "I have read the license agreement and accept it"
: "Ik heb de licentie voorwaarden gelezen en accepteer deze"

, "License Agreement"
: "Licentie voorwaarden"

, "I have read the privacy agreement and accept it"
: "Ik heb de privacy voorwaarden gelezen en accepteer deze"

, "Privacy Agreement"
: "Privacy voorwaarden"

, "Accept Terms and Conditions"
: "Accepteer de voorwaarden"

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: "Resultaat"

, "Error"
: "Fout"

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Install application"
: "Installeer toepassing"

, "File"
: "Bestand"

, "Setup Authentication"
: ""

, "Database"
: "Database"

, "User"
: "Gebruiker"

, "Prefix"
: "Voorvoegsel"

, "Logging"
: ""

, "Filename"
: "Bestandsnaam"

, "Priority"
: "Prioriteit"

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: "Sessie"

, "Temporary files"
: "Tijdelijke bestanden"

, "Temporary Files Path"
: "Pad voor tijdelijke bestanden"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: "uitgeschakeld"

, "enabled"
: "ingeschakeld"

, "Config file is not writable"
: "Configuratie bestand is niet beschrijfbaar"

, "Save config"
: "Opslaan configuratie"

, "Download config file"
: "Download configuratie bestand"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Voorwaarden"

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: "Email"

, "Application Manager"
: ""

, "Delete all existing users and groups"
: "Verwijder alle bestaande gebruikers en groepen"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: ""

, "Login name"
: "Login naam"

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: "Zoekfilter"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Wachtwoord instellingen"

, "User can change password"
: "Gebruiker mag wachtwoord wijzigen"

, "Enable password policy"
: ""

, "Only ASCII"
: "Uitsluitend ASCII "

, "Minimum length"
: "Minimumlengte"

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: "Minimum aantal hoofdletters"

, "Minimum special chars"
: "Minimum aantal speciale tekens"

, "Minimum numbers"
: "Minimum aantal cijfers"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Passwords don't match"
: "Wachtwoorden komen niet overeen"

, "Should not be empty"
: ""

, "Setup"
: ""

, "Application, Applications"
: [
  "Toepassing"
 ,"Toepassingen"

]
, "Name"
: "Naam"

, "Enabled"
: "Ingeschakeld"

, "Order"
: ""

, "Installed Version"
: "Geïnstalleerde versie"

, "Available Version"
: "Beschikbare versie"

, "Status"
: "Status"

, "Depends on"
: "Afhankelijk van"

, "Uninstall application"
: "De-installeer toepassing"

, "Update application"
: "Toepassing bewerken"

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: "Dit kan even duren"

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Application"
: "Toepassing"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Ik heb de licentie voorwaarden gelezen en accepteer deze"

, "License Agreement"
: "Licentie voorwaarden"

, "I have read the privacy agreement and accept it"
: "Ik heb de privacy voorwaarden gelezen en accepteer deze"

, "Privacy Agreement"
: "Privacy voorwaarden"

, "Accept Terms and Conditions"
: "Accepteer de voorwaarden"

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: "Imap"

, "Hostname"
: ""

, "Username"
: "Gebruikersnaam"

, "Password"
: "Wachtwoord"

, "Port"
: "Poort"

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: "Nee"

, "Yes"
: "Ja"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: ""

, "MySql Database"
: ""

, "MySql User"
: ""

, "MySql Password"
: ""

, "MySql Port"
: ""

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: "Voorwaarden"

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: "Email"

, "Application Manager"
: ""

, "Setup"
: ""

, "Name"
: "Naam"

, "Enabled"
: "Ingeschakeld"

, "Order"
: ""

, "Installed Version"
: "Geïnstalleerde versie"

, "Available Version"
: "Beschikbare versie"

, "Status"
: "Status"

, "Depends on"
: "Afhankelijk van"

, "Install application"
: "Installeer toepassing"

, "Uninstall application"
: "De-installeer toepassing"

, "Update application"
: "Toepassing bewerken"

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: "Dit kan even duren"

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Verwijder alle bestaande gebruikers en groepen"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: ""

, "Login name"
: "Login naam"

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: "Zoekfilter"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Wachtwoord instellingen"

, "User can change password"
: "Gebruiker mag wachtwoord wijzigen"

, "Enable password policy"
: ""

, "Only ASCII"
: "Uitsluitend ASCII "

, "Minimum length"
: "Minimumlengte"

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: "Minimum aantal hoofdletters"

, "Minimum special chars"
: "Minimum aantal speciale tekens"

, "Minimum numbers"
: "Minimum aantal cijfers"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: "Opslaan configuratie"

, "Passwords don't match"
: "Wachtwoorden komen niet overeen"

, "Should not be empty"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: ""

, "Result"
: "Resultaat"

, "Error"
: "Fout"

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Application, Applications"
: [
  "Toepassing"
 ,"Toepassingen"

]
, "File"
: "Bestand"

, "Setup Authentication"
: ""

, "Database"
: "Database"

, "User"
: "Gebruiker"

, "Prefix"
: "Voorvoegsel"

, "Logging"
: ""

, "Filename"
: "Bestandsnaam"

, "Priority"
: "Prioriteit"

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: "Sessie"

, "Temporary files"
: "Tijdelijke bestanden"

, "Temporary Files Path"
: "Pad voor tijdelijke bestanden"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: "uitgeschakeld"

, "enabled"
: "ingeschakeld"

, "Config file is not writable"
: "Configuratie bestand is niet beschrijfbaar"

, "Download config file"
: "Download configuratie bestand"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Toepassing"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
